Introduction — Kedro 0.17.6 documentation

# Introduction

We welcome any and all contributions to Kedro, at whatever level you can manage. For example, you could:

- Join the community on Discord

- Troubleshoot other users’ questions or get answers to your own queries on GitHub discussions

- Make a pull request on the kedro-community Github repo to update the curated list of Kedro community content.

- Report a bug or propose a new feature on GitHub issues

- Review other contributors’ PRs

- Contribute code, for example to fix a bug or add a feature

- Contribute to the documentation